package com.secutix.plugin.urlshortener.google;

import com.secutix.plugin.util.HttpClientHelper;
import com.secutix.plugin.util.StxPluginHttpResponse;
import com.secutix.plugin.util.impl.InterfaceParametersProviderDefaultImpl;
import org.apache.http.HttpEntity;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import static org.mockito.Mockito.*;

import java.util.Map;

/**
 * Created by lkl on 03.10.2018.
 */
public class TestGoogleUrlShortenerPlugin {

    private GoogleUrlShortenerPlugin plugin;
    private InterfaceParametersProviderDefaultImpl interfaceParameterProvider;
    private StxPluginHttpResponse resp;
    private HttpClientHelper httpClientHelper;

    @Before
    public void init() {
        plugin = new GoogleUrlShortenerPlugin();
        interfaceParameterProvider = (InterfaceParametersProviderDefaultImpl) plugin.getInterfaceParametersProvider();
        interfaceParameterProvider.getParameters().put("url", "https://www.googleapis.com/urlshortener/v1/url"); //Default google url API
        interfaceParameterProvider.getParameters().put("login", "Not relevant");
        interfaceParameterProvider.getParameters().put("password", "Dummy");//Here we store google API key
        resp = new StxPluginHttpResponse(200, "{ \"id\": \"https://goo.gl/veryShort\"}");
        httpClientHelper = mock(HttpClientHelper.class);
        plugin.setHttpClientHelper(httpClientHelper);

        when(httpClientHelper.doPost(any(String.class), any(Map.class), any(Map.class))).thenReturn(resp);

    }

    @Test
    public void validate(){
        try {
            plugin.validate();
        } catch (Exception e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testBasicCase() {
        ShortUrlCallResult res = plugin.shortenUrl("https://google.com");
        Assert.assertTrue(res.isSuccess());
        Assert.assertEquals("https://goo.gl/veryShort", res.getShortUrl());

    }

    @Test
    public void testEdgeCases(){
        try {
            ShortUrlCallResult res = plugin.shortenUrl(null);
            Assert.assertFalse(res.isSuccess());
            res = plugin.shortenUrl("");
            Assert.assertFalse(res.isSuccess());
        } catch (Exception e) {
            Assert.fail(e.getMessage());
        }
    }

}
